@@ -10,30 +10,30 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.9-89.9.AXS2.src.rpm ]
+if [ ! -r kernel-2.6.9-89.13.AXS2.src.rpm ]
 then
-    wget http://ftp.miraclelinux.com/pub/Miracle/ia32/standard/4.0/updates/SRPMS/kernel-2.6.9-89.9.AXS2.src.rpm || die "Can't download source package."
+    wget http://ftp.miraclelinux.com/pub/Miracle/ia32/standard/4.0/updates/SRPMS/kernel-2.6.9-89.13.AXS2.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-2.6.9-89.9.AXS2.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-2.6.9-89.9.AXS2.src.rpm || die "Can't install source package."
+rpm --checksig kernel-2.6.9-89.13.AXS2.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-2.6.9-89.13.AXS2.src.rpm || die "Can't install source package."
 
 cd /usr/src/asianux/SOURCES/ || die "Can't chdir to /usr/src/asianux/SOURCES/ ."
-if [ ! -r ccs-patch-1.7.2-20100412.tar.gz ]
+if [ ! -r ccs-patch-1.7.2-20100923.tar.gz ]
 then
-    wget http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.2-20100412.tar.gz || die "Can't download patch."
+    wget http://sourceforge.jp/frs/redir.php?f=/tomoyo/43375/ccs-patch-1.7.2-20100923.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 cp -p /usr/src/asianux/SPECS/kernel-2.6.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-2.6.spec	2010-02-08 18:13:39.000000000 +0900
-+++ kernel-2.6.spec	2010-02-24 17:12:32.000000000 +0900
+--- kernel-2.6.spec
++++ kernel-2.6.spec
 @@ -26,7 +26,7 @@
  # that the kernel isn't the stock distribution kernel, for example by
  # adding some text to the end of the version number.
  #
--%define release 89.9%{?dist}
-+%define release 89.9%{?dist}_tomoyo_1.7.2
+-%define release 89.13%{?dist}
++%define release 89.13%{?dist}_tomoyo_1.7.2p3
  %define sublevel 9
  %define kversion 2.6.%{sublevel}
  %define rpmversion 2.6.%{sublevel}
@@ -56,18 +56,18 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  Version: %{rpmversion}
-@@ -6136,6 +6139,10 @@
+@@ -6238,6 +6241,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.7.2-20100412.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.7.2-20100923.tar.gz
 +patch -sp1 < patches/ccs-patch-2.6.9-asianux-2.diff
 +
  cp %{SOURCE10} Documentation/
  
  mkdir configs
-@@ -6147,6 +6154,9 @@
+@@ -6249,6 +6256,9 @@
  for i in *.config 
  do 
  	mv $i .config 
@@ -88,5 +88,30 @@ echo "to build kernel rpm packages."
 echo ""
 echo "I'll start 'rpmbuild -bb --target i686 /tmp/ccs-kernel.spec' in 30 seconds. Press Ctrl-C to stop."
 sleep 30
+patch << "EOF" || die "Can't patch spec file."
+--- /tmp/ccs-kernel.spec
++++ /tmp/ccs-kernel.spec
+@@ -3,14 +3,14 @@
+ # What parts do we want to build?  We must build at least one kernel.
+ # These are the kernels that are built IF the architecture allows it.
+ 
+-%define buildup 1
++%define buildup 0
+ %define buildsmp 1
+-%define buildsource 1
+-%define buildhugemem 1
+-%define buildlargesmp 1
++%define buildsource 0
++%define buildhugemem 0
++%define buildlargesmp 0
+ %define builddoc 0
+-%define buildxen 1
+-%define kabi 1
++%define buildxen 0
++%define kabi 0
+ 
+ %define FC2 0
+ %define FC3 0
+EOF
 exec rpmbuild -bb --target i686 /tmp/ccs-kernel.spec
 exit 0
