@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2010  NTT DATA CORPORATION
  *
- * Version: 1.7.2   2010/04/01
+ * Version: 1.7.2+   2010/06/04
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -46,7 +46,6 @@ void __init ccs_signal_init(void);
 void __init ccs_capability_init(void);
 void __init ccs_mount_init(void);
 void __init ccs_maymount_init(void);
-void __init ccs_autobind_init(void);
 
 /* Index numbers for Access Controls. */
 enum ccs_acl_entry_type_index {
@@ -507,13 +506,43 @@ struct ccs_execve_entry;
 
 /* Structure for request info. */
 struct ccs_request_info {
-	struct ccs_domain_info *domain;
+	/*
+	 * For holding parameters specific to operations which deal files.
+	 */
 	struct ccs_obj_info *obj;
+	/*
+	 * For holding parameters specific to execve() request.
+	 */
 	struct ccs_execve_entry *ee;
+	/*
+	 * For updating current->ccs_flags at ccs_update_task_state().
+	 * Initialized to NULL at ccs_init_request_info().
+	 * Matching "struct ccs_acl_info"->cond is copied if access request was
+	 * granted. Re-initialized to NULL at ccs_update_task_state().
+	 */
 	struct ccs_condition *cond;
+	/*
+	 * For counting number of retries made for this request.
+	 * This counter is incremented whenever ccs_supervisor() returned
+	 * CCS_RETRY_REQUEST.
+	 */
 	u8 retry;
+	/*
+	 * For holding profile number used for this request.
+	 * One of values between 0 and CCS_MAX_PROFILES - 1.
+	 */
 	u8 profile;
+	/*
+	 * For holding access control mode used for this request.
+	 * One of CCS_CONFIG_DISABLED, CCS_CONFIG_LEARNING,
+	 * CCS_CONFIG_PERMISSIVE, CCS_CONFIG_ENFORCING.
+	 */
 	u8 mode;
+	/*
+	 * For holding operation index used for this request.
+	 * Used by ccs_init_request_info() / ccs_get_mode() / 
+	 * ccs_write_audit_log(). One of values in "enum ccs_mac_index".
+	 */
 	u8 type;
 };
 
@@ -537,6 +566,8 @@ struct ccs_execve_entry {
 	/* For execute_handler */
 	const struct ccs_path_info *handler;
 	char *handler_path; /* = kstrdup(handler->name, CCS_GFP_FLAGS) */
+	u8 handler_type; /* = CCS_TYPE_EXECUTE_HANDLER or
+			    CCS_TYPE_DENIED_EXECUTE_HANDLER */
 	/* For dumping argv[] and envp[]. */
 	struct ccs_page_dump dump;
 	/* For temporary use. */
@@ -937,8 +968,7 @@ int ccs_exec_perm(struct ccs_request_info *r,
 		  const struct ccs_path_info *filename);
 int ccs_get_mode(const u8 profile, const u8 index);
 int ccs_get_path(const char *pathname, struct path *path);
-int ccs_init_request_info(struct ccs_request_info *r,
-			  struct ccs_domain_info *domain, const u8 index);
+int ccs_init_request_info(struct ccs_request_info *r, const u8 index);
 int ccs_lock(void);
 int ccs_may_transit(const char *domainname, const char *pathname);
 int ccs_open_control(const u8 type, struct file *file);
@@ -1206,7 +1236,22 @@ extern unsigned int ccs_quota_for_query;
 
 #include <linux/dcache.h>
 
-#ifdef D_PATH_DISCONNECT
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 36)
+
+#include <linux/lglock.h>
+DECLARE_BRLOCK(vfsmount_lock);
+static inline void ccs_realpath_lock(void)
+{
+	spin_lock(&dcache_lock);
+	br_read_lock(vfsmount_lock);
+}
+static inline void ccs_realpath_unlock(void)
+{
+	br_read_unlock(vfsmount_lock);
+	spin_unlock(&dcache_lock);
+}
+
+#elif defined(D_PATH_DISCONNECT) && !defined(CONFIG_SUSE_KERNEL)
 
 static inline void ccs_realpath_lock(void)
 {
